/*
 * CONTRAT DE LICENCE DE LOGICIEL LIBRE CeCILL-B
 * https://cecill.info/licences/Licence_CeCILL-B_V1-fr.html
 */
package fr.unistra.sil.erp.back.controller.api;

import static fr.unistra.sil.erp.back.WebMvcConfig.MAPPING_GETCATEGORIES;
import fr.unistra.sil.erp.back.DatabaseSystem;
import fr.unistra.sil.erp.back.controller.IRetrieveCategoriesController;
import fr.unistra.sil.erp.back.model.Category;
import fr.unistra.sil.erp.back.db.DatabaseConnectionException;
import java.util.List;
import java.util.logging.Level;
import java.util.logging.Logger;
import org.springframework.http.HttpStatus;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.RestController;
import fr.unistra.sil.erp.back.db.IDatabase;

/**
 * REST controller for the category list.
 * @author BEAUVAIS ANTOINE
 */
@RestController
public class ApiRetrieveCategoriesController
        implements IRetrieveCategoriesController {
    
    /**
     * Returns the list of categories in JSON format.
     * @return the HTTP response.
     * @throws ApiServerErrorException Database failure.
     */
    @GetMapping(MAPPING_GETCATEGORIES)
    @Override
    public ResponseEntity<Object> getCategories() throws ApiServerErrorException
    {
        IDatabase db;
        try {
            db = DatabaseSystem.getInstance();
        } catch (DatabaseConnectionException ex) {
            Logger.getLogger(ApiRetrieveCategoriesController.class.getName())
                    .log(Level.SEVERE, "Failed to connect to database.", ex);
            throw new ApiServerErrorException("Database failure.");
        }
        
        List<Category> res = db.getCategories();
        if(res == null)
            throw new ApiServerErrorException("Database failure.");
        
        return new ResponseEntity<>(res, HttpStatus.OK);
    }
    
}
